@@ -4,6 +4,7 @@ from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import unicode_literals
 
+import os
 import six
 import datetime
 import operator
@@ -12,6 +13,7 @@ import tableschema
 from . import cells
 from copy import copy
 from multiprocessing.pool import ThreadPool
+from six.moves.urllib.parse import urlparse
 from .registry import registry
 from .error import Error
 from . import exceptions
@@ -174,6 +176,9 @@ class Inspector(object):
             if schema is None:
                 checks = _filter_checks(checks, type='schema', inverse=True)
         except Exception as exception:
+            if _local_file_not_found(source):
+                message = "No such file or directory: '%s'" % source
+                exception = tabulator.exceptions.IOError(message)
             fatal_error = True
             error = _compose_error_from_exception(exception)
             errors.append(error)
@@ -309,6 +314,11 @@ def _filter_checks(checks, type=None, context=None, inverse=False):
     return result
 
 
+def _local_file_not_found(source):
+    return urlparse(source).scheme == '' \
+           and not os.path.isfile(source)
+
+
 def _compose_error_from_exception(exception):
     code = 'source-error'
     message = str(exception)
